.. :changelog:

=======
History
=======


0.5.3 (04112018)
----------------

* Update shelf icons for Maya 2018
* Fix missing imports in setup.py testit and cheeseit commands


0.3.0 (03312016)
----------------

* Added MatteAOV serialization

  * api methods (save_mattes, load_mattes)
  * added menubar supporting serialization to MatteDialog


0.2.0 (03302016)
----------------

* Added HDR Light Rig
* Added rename method to MatteAOV model
* Added rename functionality to mtoatools.mattes UI

  * double click to edit name
  * enter to finish editing
  * escape to cancel rename



0.1.0 (09122015)
---------------------

* First release on PyPI.
